@@ -90,10 +90,10 @@ def max_age(request):
 
 
 def verify_uri(
-        endpoint_context: EndpointContext,
-        request: Union[dict, Message],
-        uri_type: str,
-        client_id: Optional[str] = None,
+    endpoint_context: EndpointContext,
+    request: Union[dict, Message],
+    uri_type: str,
+    client_id: Optional[str] = None,
 ):
     """
     A redirect URI
@@ -129,7 +129,10 @@ def verify_uri(
     if client_info is None:
         raise KeyError("No such client")
 
-    redirect_uris = client_info.get(f"{uri_type}s")
+    if uri_type == "redirect_uri":
+        redirect_uris = client_info.get(f"{uri_type}s")
+    else:
+        redirect_uris = client_info.get(f"{uri_type}")
 
     if redirect_uris is None:
         raise RedirectURIError(f"No registered {uri_type} for {_cid}")
@@ -220,10 +223,10 @@ def get_uri(endpoint_context, request, uri_type):
 
 
 def authn_args_gather(
-        request: Union[AuthorizationRequest, dict],
-        authn_class_ref: str,
-        cinfo: dict,
-        **kwargs,
+    request: Union[AuthorizationRequest, dict],
+    authn_class_ref: str,
+    cinfo: dict,
+    **kwargs,
 ):
     """
     Gather information to be used by the authentication method
@@ -530,13 +533,13 @@ class Authorization(Endpoint):
         return json.loads(as_unicode(_id))
 
     def setup_auth(
-            self,
-            request: Optional[Union[Message, dict]],
-            redirect_uri: str,
-            cinfo: dict,
-            cookie: List[dict] = None,
-            acr: str = None,
-            **kwargs,
+        self,
+        request: Optional[Union[Message, dict]],
+        redirect_uri: str,
+        cinfo: dict,
+        cookie: List[dict] = None,
+        acr: str = None,
+        **kwargs,
     ) -> dict:
         """
 
@@ -659,12 +662,12 @@ class Authorization(Endpoint):
         return ""
 
     def response_mode(
-            self,
-            request: Union[dict, AuthorizationRequest],
-            response_args: Optional[Union[dict, AuthorizationResponse]] = None,
-            return_uri: Optional[str] = "",
-            fragment_enc: Optional[bool] = None,
-            **kwargs,
+        self,
+        request: Union[dict, AuthorizationRequest],
+        response_args: Optional[Union[dict, AuthorizationResponse]] = None,
+        return_uri: Optional[str] = "",
+        fragment_enc: Optional[bool] = None,
+        **kwargs,
     ) -> dict:
         resp_mode = request["response_mode"]
         if resp_mode == "form_post":
@@ -963,10 +966,10 @@ class Authorization(Endpoint):
         return kwargs
 
     def process_request(
-            self,
-            request: Optional[Union[Message, dict]] = None,
-            http_info: Optional[dict] = None,
-            **kwargs,
+        self,
+        request: Optional[Union[Message, dict]] = None,
+        http_info: Optional[dict] = None,
+        **kwargs,
     ):
         """The AuthorizationRequest endpoint
 
