@@ -36,7 +36,7 @@ class TokenEndpointHelper(object):
         self.error_cls = self.endpoint.error_cls
 
     def post_parse_request(
-            self, request: Union[Message, dict], client_id: Optional[str] = "", **kwargs
+        self, request: Union[Message, dict], client_id: Optional[str] = "", **kwargs
     ):
         """Context specific parsing of the request.
         This is done after general request parsing and before processing
@@ -49,15 +49,15 @@ class TokenEndpointHelper(object):
         raise NotImplementedError
 
     def _mint_token(
-            self,
-            token_class: str,
-            grant: Grant,
-            session_id: str,
-            client_id: str,
-            based_on: Optional[SessionToken] = None,
-            scope: Optional[list] = None,
-            token_args: Optional[dict] = None,
-            token_type: Optional[str] = "",
+        self,
+        token_class: str,
+        grant: Grant,
+        session_id: str,
+        client_id: str,
+        based_on: Optional[SessionToken] = None,
+        scope: Optional[list] = None,
+        token_args: Optional[dict] = None,
+        token_type: Optional[str] = "",
     ) -> SessionToken:
         _context = self.endpoint.server_get("endpoint_context")
         _mngr = _context.session_manager
@@ -171,9 +171,9 @@ class AccessTokenHelper(TokenEndpointHelper):
                     _response["expires_in"] = token.expires_at - utc_time_sans_frac()
 
         if (
-                issue_refresh
-                and "refresh_token" in _supports_minting
-                and "refresh_token" in grant_types_supported
+            issue_refresh
+            and "refresh_token" in _supports_minting
+            and "refresh_token" in grant_types_supported
         ):
             try:
                 refresh_token = self._mint_token(
@@ -196,7 +196,7 @@ class AccessTokenHelper(TokenEndpointHelper):
         return _response
 
     def post_parse_request(
-            self, request: Union[Message, dict], client_id: Optional[str] = "", **kwargs
+        self, request: Union[Message, dict], client_id: Optional[str] = "", **kwargs
     ):
         """
         This is where clients come to get their access tokens
@@ -300,9 +300,9 @@ class RefreshTokenHelper(TokenEndpointHelper):
         token.register_usage()
 
         if (
-                "client_id" in req
-                and req["client_id"] in _context.cdb
-                and "revoke_refresh_on_issue" in _context.cdb[req["client_id"]]
+            "client_id" in req
+            and req["client_id"] in _context.cdb
+            and "revoke_refresh_on_issue" in _context.cdb[req["client_id"]]
         ):
             revoke_refresh = _context.cdb[req["client_id"]].get("revoke_refresh_on_issue")
         else:
@@ -314,7 +314,7 @@ class RefreshTokenHelper(TokenEndpointHelper):
         return _resp
 
     def post_parse_request(
-            self, request: Union[Message, dict], client_id: Optional[str] = "", **kwargs
+        self, request: Union[Message, dict], client_id: Optional[str] = "", **kwargs
     ):
         """
         This is where clients come to refresh their access tokens
@@ -405,10 +405,10 @@ class TokenExchangeHelper(TokenEndpointHelper):
         try:
             request.verify(keyjar=keyjar, opponent_id=client_id)
         except (
-                MissingRequiredAttribute,
-                ValueError,
-                MissingRequiredValue,
-                JWKESTException,
+            MissingRequiredAttribute,
+            ValueError,
+            MissingRequiredValue,
+            JWKESTException,
         ) as err:
             return self.endpoint.error_cls(error="invalid_request", error_description="%s" % err)
 
@@ -449,8 +449,8 @@ class TokenExchangeHelper(TokenEndpointHelper):
             )
 
         if (
-                "requested_token_type" in request
-                and request["requested_token_type"] not in config["requested_token_types_supported"]
+            "requested_token_type" in request
+            and request["requested_token_type"] not in config["requested_token_types_supported"]
         ):
             return TokenErrorResponse(
                 error="invalid_request",
@@ -525,7 +525,8 @@ class TokenExchangeHelper(TokenEndpointHelper):
 
         token = _mngr.find_token(_session_info["session_id"], request["subject_token"])
         _requested_token_type = request.get(
-            "requested_token_type", "urn:ietf:params:oauth:token-type:access_token")
+            "requested_token_type", "urn:ietf:params:oauth:token-type:access_token"
+        )
 
         _token_class = self.token_types_mapping[_requested_token_type]
 
@@ -604,14 +605,14 @@ def validate_token_exchange_policy(request, context, subject_token, **kwargs):
         )
 
     if (
-            "requested_token_type" in request
-            and request["requested_token_type"] == "urn:ietf:params:oauth:token-type:refresh_token"
+        "requested_token_type" in request
+        and request["requested_token_type"] == "urn:ietf:params:oauth:token-type:refresh_token"
     ):
         if "offline_access" not in subject_token.scope:
             return TokenErrorResponse(
                 error="invalid_request",
                 error_description=f"Exchange {request['subject_token_type']} to refresh token "
-                                  f"forbbiden",
+                f"forbbiden",
             )
 
     if "scope" in request:
