@@ -12,6 +12,7 @@ from idpyoidc.server.authn_event import AuthnEvent
 from idpyoidc.server.token import Token as TokenHandler
 from idpyoidc.util import importer
 
+from ...message.oauth2 import TokenExchangeRequest
 from . import MintingNotAllowed
 from .claims import claims_match
 from .token import AccessToken
@@ -20,7 +21,6 @@ from .token import IDToken
 from .token import Item
 from .token import RefreshToken
 from .token import SessionToken
-from ...message.oauth2 import TokenExchangeRequest
 
 logger = logging.getLogger(__name__)
 
@@ -34,11 +34,11 @@ class GrantMessage(ImpExp):
     }
 
     def __init__(
-            self,
-            scope: Optional[str] = "",
-            authorization_details: Optional[dict] = None,
-            claims: Optional[list] = None,
-            resources: Optional[list] = None,
+        self,
+        scope: Optional[str] = "",
+        authorization_details: Optional[dict] = None,
+        claims: Optional[list] = None,
+        resources: Optional[list] = None,
     ):
         ImpExp.__init__(self)
         self.scope = scope
@@ -128,24 +128,24 @@ class Grant(Item):
     }
 
     def __init__(
-            self,
-            scope: Optional[list] = None,
-            claims: Optional[dict] = None,
-            resources: Optional[list] = None,
-            authorization_details: Optional[dict] = None,
-            authorization_request: Optional[Message] = None,
-            authentication_event: Optional[AuthnEvent] = None,
-            issued_token: Optional[list] = None,
-            usage_rules: Optional[dict] = None,
-            issued_at: int = 0,
-            expires_in: int = 0,
-            expires_at: int = 0,
-            revoked: bool = False,
-            token_map: Optional[dict] = None,
-            sub: Optional[str] = "",
-            extra: Optional[Dict[str, str]] = None,
-            remember_token: Optional[Callable] = None,
-            remove_inactive_token: Optional[bool] = False
+        self,
+        scope: Optional[list] = None,
+        claims: Optional[dict] = None,
+        resources: Optional[list] = None,
+        authorization_details: Optional[dict] = None,
+        authorization_request: Optional[Message] = None,
+        authentication_event: Optional[AuthnEvent] = None,
+        issued_token: Optional[list] = None,
+        usage_rules: Optional[dict] = None,
+        issued_at: int = 0,
+        expires_in: int = 0,
+        expires_at: int = 0,
+        revoked: bool = False,
+        token_map: Optional[dict] = None,
+        sub: Optional[str] = "",
+        extra: Optional[Dict[str, str]] = None,
+        remember_token: Optional[Callable] = None,
+        remove_inactive_token: Optional[bool] = False,
     ):
         Item.__init__(
             self,
@@ -203,13 +203,13 @@ class Grant(Item):
         return False
 
     def payload_arguments(
-            self,
-            session_id: str,
-            endpoint_context,
-            item: SessionToken,
-            claims_release_point: str,
-            extra_payload: Optional[dict] = None,
-            secondary_identifier: str = "",
+        self,
+        session_id: str,
+        endpoint_context,
+        item: SessionToken,
+        claims_release_point: str,
+        extra_payload: Optional[dict] = None,
+        secondary_identifier: str = "",
     ) -> dict:
         """
 
@@ -271,19 +271,19 @@ class Grant(Item):
         return payload
 
     def mint_token(
-            self,
-            session_id: str,
-            endpoint_context: object,
-            token_class: str,
-            token_handler: TokenHandler = None,
-            based_on: Optional[SessionToken] = None,
-            usage_rules: Optional[dict] = None,
-            scope: Optional[list] = None,
-            token_type: Optional[str] = "",
-            expires_in: Optional[int] = 0,
-            not_before: Optional[int] = 0,
-            claims: Optional[List[str]] = None,
-            **kwargs,
+        self,
+        session_id: str,
+        endpoint_context: object,
+        token_class: str,
+        token_handler: TokenHandler = None,
+        based_on: Optional[SessionToken] = None,
+        usage_rules: Optional[dict] = None,
+        scope: Optional[list] = None,
+        token_type: Optional[str] = "",
+        expires_in: Optional[int] = 0,
+        not_before: Optional[int] = 0,
+        claims: Optional[List[str]] = None,
+        **kwargs,
     ) -> Optional[SessionToken]:
         """
 
@@ -406,10 +406,7 @@ class Grant(Item):
         return None
 
     def revoke_token(
-            self,
-            value: Optional[str] = "",
-            based_on: Optional[str] = "",
-            recursive: bool = True
+        self, value: Optional[str] = "", based_on: Optional[str] = "", recursive: bool = True
     ):
         remain = []
         for t in self.issued_token:
@@ -504,22 +501,22 @@ class ExchangeGrant(Grant):
     type = "exchange_grant"
 
     def __init__(
-            self,
-            scope: Optional[list] = None,
-            claims: Optional[dict] = None,
-            resources: Optional[list] = None,
-            authorization_details: Optional[dict] = None,
-            issued_token: Optional[list] = None,
-            usage_rules: Optional[dict] = None,
-            exchange_request: Optional[TokenExchangeRequest] = None,
-            original_session_id: str = "",
-            issued_at: int = 0,
-            expires_in: int = 0,
-            expires_at: int = 0,
-            revoked: bool = False,
-            token_map: Optional[dict] = None,
-            users: list = None,
-            sub: Optional[str] = "",
+        self,
+        scope: Optional[list] = None,
+        claims: Optional[dict] = None,
+        resources: Optional[list] = None,
+        authorization_details: Optional[dict] = None,
+        issued_token: Optional[list] = None,
+        usage_rules: Optional[dict] = None,
+        exchange_request: Optional[TokenExchangeRequest] = None,
+        original_session_id: str = "",
+        issued_at: int = 0,
+        expires_in: int = 0,
+        expires_at: int = 0,
+        revoked: bool = False,
+        token_map: Optional[dict] = None,
+        users: list = None,
+        sub: Optional[str] = "",
     ):
         Grant.__init__(
             self,
@@ -534,7 +531,7 @@ class ExchangeGrant(Grant):
             expires_at=expires_at,
             revoked=revoked,
             token_map=token_map,
-            sub=sub
+            sub=sub,
         )
 
         self.users = users or []
